.. include:: ../../README.rst


.. toctree::
   :caption: Installation Guide
   :maxdepth: 1

   install/core
   install/database
   install/plugins


.. toctree::
   :caption: User's Guide
   :maxdepth: 1

   user/pytorch
   user/monitoring
   user/searchspace
   user/algorithms
   user/script
   user/evc

.. toctree::
   :caption: Examples
   :maxdepth: 1

   examples/pytorch_cifar
   examples/pytorch_a2c_ppo
   examples/cluster

.. toctree::
   :caption: Plugin development's Guide
   :maxdepth: 1

   plugins/base
   plugins/algorithms
   plugins/database
   plugins/analysis


.. .. toctree::
..    :caption: Plan

..    roadmap
..    changelog
..    contributors


.. toctree::
   :maxdepth: 2
   :caption: Code Reference

   code/core
   code/algo
   code/client

.. toctree::
   :caption: Developer's Guide
   :maxdepth: 1

   developer/testing
   developer/documenting
   developer/standards

.. Don't fetch reference/viz
